@@ -8,4 +8,6 @@ class OrchestratorConstants:
         self.APIPORTDESC = 'the port address you would like FreeTAKServer to run receive datapackages on not'
         self.IPDESC = "the IP you would like FreeTAKServer to run receive connections on, must be set for private DataPackages to function"
         self.COTPORTDESC = 'the port you would like FreeTAKServer to run receive connections on'
-        self.FULLDESC = 'FreeTAKServer startup settings'
\ No newline at end of file
+        self.FULLDESC = 'FreeTAKServer startup settings'
+        self.HEALTHCHECK = 'HealthCheck'
+        self.LOCALHOST = '127.0.0.1'
\ No newline at end of file
