@@ -3,6 +3,6 @@ from .Group import Group
 class Hierarchy:
     def __init__(self, xml):
         try:
-            self.Group = Group(xml.find('group'))
+            self.m_Group = Group(xml.find('group'))
         except:
             pass
\ No newline at end of file
