@@ -1,6 +1,8 @@
 class Uid:
-    def __init__(self):
-        self.Droid = ''
+    def __init__(self, xml):
+        self.Droid = None
+        self.setDroid(xml.get('Droid'))
+
     def getDroid(self):
         return self.Droid
     def setDroid(self, Droid):
