@@ -1,16 +1,9 @@
-from ._GroupVariables import _GroupVariables as vars
-
 class _Group:
-    def __init__(self):
+    def __init__(self, xml):
         self.name = None
         self.role = None
-
-    @staticmethod
-    def connection(NAME = vars.connection().NAME, ROLE = vars.connection().ROLE):
-        _group = _Group()
-        _group.setname(NAME)
-        _group.setrole(ROLE)
-        return _group
+        self.setname(xml.get('name'))
+        self.setrole(xml.get('role'))
 
     def getrole(self):
         return self.role
